==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-geographic-shape-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
export let IgcGeographicShapeSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicShapeSeriesComponent extends IgcGeographicShapeSeriesBaseComponent {
        createImplementation() {
            return new GeographicShapeSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._styleShape = null;
            this._styleShape_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicShapeSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = names;
            }
            return IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent;
        }
        static register() {
            if (!IgcGeographicShapeSeriesComponent._isElementRegistered) {
                IgcGeographicShapeSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicShapeSeriesComponent.htmlTagName, IgcGeographicShapeSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a polygon shape.
        */
        get isPolygon() {
            return this.i.e4;
        }
        /**
         * Gets or sets the fill brush.
        */
        get shapeFill() {
            return this.i.wk ? this.i.wk.fill : null;
        }
        set shapeFill(v) {
            this.ensureShapeStyle();
            this.i.wk.fill = v;
        }
        /**
         * Gets or sets the stroke brush.
        */
        get shapeStroke() {
            return this.i.wk ? this.i.wk.stroke : null;
        }
        set shapeStroke(v) {
            this.ensureShapeStyle();
            this.i.wk.stroke = v;
        }
        /**
         * Gets or sets the stroke thickness.
        */
        get shapeStrokeThickness() {
            return this.i.wk ? this.i.wk.strokeThickness : NaN;
        }
        set shapeStrokeThickness(v) {
            this.ensureShapeStyle();
            this.i.wk.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.wk.strokeThickness);
        }
        /**
         * Gets or sets the opacity.
        */
        get shapeOpacity() {
            return this.i.wk ? this.i.wk.opacity : NaN;
        }
        set shapeOpacity(v) {
            this.ensureShapeStyle();
            this.i.wk.opacity = +v;
            this._a("shapeOpacity", this.i.wk.opacity);
        }
        ensureShapeStyle() {
            if (this.i.wk) {
                return;
            }
            this.i.wk = new Style();
        }
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get markerType() {
            return this.i.ve;
        }
        set markerType(v) {
            this.i.ve = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.ve));
        }
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get markerOutlineMode() {
            return this.i.vd;
        }
        set markerOutlineMode(v) {
            this.i.vd = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.vd));
        }
        /**
         * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
        */
        get markerFillMode() {
            return this.i.vc;
        }
        set markerFillMode(v) {
            this.i.vc = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.vc));
        }
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get markerTemplate() {
            return this.i.v0;
        }
        set markerTemplate(v) {
            this.i.v0 = v;
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get markerBrush() {
            return brushToString(this.i.wh);
        }
        set markerBrush(v) {
            this.i.wh = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.wh));
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get markerOutline() {
            return brushToString(this.i.wi);
        }
        set markerOutline(v) {
            this.i.wi = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.wi));
        }
        /**
         * Gets or sets thickness of the marker outline
        */
        get markerThickness() {
            return this.i.vh;
        }
        set markerThickness(v) {
            this.i.vh = +v;
            this._a("markerThickness", this.i.vh);
        }
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get markerCollisionAvoidance() {
            return this.i.vb;
        }
        set markerCollisionAvoidance(v) {
            this.i.vb = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.vb));
        }
        /**
         * Gets the effective marker template for the current series object.
        */
        get actualMarkerTemplate() {
            return this.i.vz;
        }
        set actualMarkerTemplate(v) {
            this.i.vz = v;
        }
        /**
         * Gets the effective marker brush for the current series object.
        */
        get actualMarkerBrush() {
            return brushToString(this.i.wf);
        }
        set actualMarkerBrush(v) {
            this.i.wf = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.wf));
        }
        /**
         * Gets the effective marker outline for the current series object.
        */
        get actualMarkerOutline() {
            return brushToString(this.i.wg);
        }
        set actualMarkerOutline(v) {
            this.i.wg = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.wg));
        }
        get styleShape() {
            return this._styleShape;
        }
        set styleShape(ev) {
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = (o, e) => {
                let outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeStyleShape) {
                    this.beforeStyleShape(this, outerArgs);
                }
                if (this._styleShape) {
                    this._styleShape(this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        }
    }
    IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = null;
    IgcGeographicShapeSeriesComponent.htmlTagName = "igc-geographic-shape-series";
    IgcGeographicShapeSeriesComponent._isElementRegistered = false;
    return IgcGeographicShapeSeriesComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-geographic-shape-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
export let IgcGeographicShapeSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicShapeSeriesComponent extends IgcGeographicShapeSeriesBaseComponent {
        createImplementation() {
            return new GeographicShapeSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._styleShape = null;
            this._styleShape_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicShapeSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = names;
            }
            return IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent;
        }
        static register() {
            if (!IgcGeographicShapeSeriesComponent._isElementRegistered) {
                IgcGeographicShapeSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicShapeSeriesComponent.htmlTagName, IgcGeographicShapeSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a polygon shape.
        */
        get isPolygon() {
            return this.i.fq;
        }
        /**
         * Gets or sets the fill brush.
        */
        get shapeFill() {
            return this.i.zq ? this.i.zq.fill : null;
        }
        set shapeFill(v) {
            this.ensureShapeStyle();
            this.i.zq.fill = v;
        }
        /**
         * Gets or sets the stroke brush.
        */
        get shapeStroke() {
            return this.i.zq ? this.i.zq.stroke : null;
        }
        set shapeStroke(v) {
            this.ensureShapeStyle();
            this.i.zq.stroke = v;
        }
        /**
         * Gets or sets the stroke thickness.
        */
        get shapeStrokeThickness() {
            return this.i.zq ? this.i.zq.strokeThickness : NaN;
        }
        set shapeStrokeThickness(v) {
            this.ensureShapeStyle();
            this.i.zq.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.zq.strokeThickness);
        }
        /**
         * Gets or sets the opacity.
        */
        get shapeOpacity() {
            return this.i.zq ? this.i.zq.opacity : NaN;
        }
        set shapeOpacity(v) {
            this.ensureShapeStyle();
            this.i.zq.opacity = +v;
            this._a("shapeOpacity", this.i.zq.opacity);
        }
        ensureShapeStyle() {
            if (this.i.zq) {
                return;
            }
            this.i.zq = new Style();
        }
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get markerType() {
            return this.i.yk;
        }
        set markerType(v) {
            this.i.yk = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.yk));
        }
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get markerOutlineMode() {
            return this.i.yj;
        }
        set markerOutlineMode(v) {
            this.i.yj = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.yj));
        }
        /**
         * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
        */
        get markerFillMode() {
            return this.i.yi;
        }
        set markerFillMode(v) {
            this.i.yi = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.yi));
        }
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get markerTemplate() {
            return this.i.y6;
        }
        set markerTemplate(v) {
            this.i.y6 = v;
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get markerBrush() {
            return brushToString(this.i.zn);
        }
        set markerBrush(v) {
            this.i.zn = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.zn));
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get markerOutline() {
            return brushToString(this.i.zo);
        }
        set markerOutline(v) {
            this.i.zo = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.zo));
        }
        /**
         * Gets or sets thickness of the marker outline
        */
        get markerThickness() {
            return this.i.yn;
        }
        set markerThickness(v) {
            this.i.yn = +v;
            this._a("markerThickness", this.i.yn);
        }
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get markerCollisionAvoidance() {
            return this.i.yh;
        }
        set markerCollisionAvoidance(v) {
            this.i.yh = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.yh));
        }
        /**
         * Gets the effective marker template for the current series object.
        */
        get actualMarkerTemplate() {
            return this.i.y5;
        }
        set actualMarkerTemplate(v) {
            this.i.y5 = v;
        }
        /**
         * Gets the effective marker brush for the current series object.
        */
        get actualMarkerBrush() {
            return brushToString(this.i.zl);
        }
        set actualMarkerBrush(v) {
            this.i.zl = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.zl));
        }
        /**
         * Gets the effective marker outline for the current series object.
        */
        get actualMarkerOutline() {
            return brushToString(this.i.zm);
        }
        set actualMarkerOutline(v) {
            this.i.zm = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.zm));
        }
        get styleShape() {
            return this._styleShape;
        }
        set styleShape(ev) {
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = (o, e) => {
                let outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeStyleShape) {
                    this.beforeStyleShape(this, outerArgs);
                }
                if (this._styleShape) {
                    this._styleShape(this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        }
    }
    IgcGeographicShapeSeriesComponent._observedAttributesIgcGeographicShapeSeriesComponent = null;
    IgcGeographicShapeSeriesComponent.htmlTagName = "igc-geographic-shape-series";
    IgcGeographicShapeSeriesComponent._isElementRegistered = false;
    return IgcGeographicShapeSeriesComponent;
})();
